# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.datacatalog_v1beta1.proto import (
    timestamps_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=b"\n$com.google.cloud.datacatalog.v1beta1B\025PolicyTagManagerProtoP\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001\252\002 Google.Cloud.DataCatalog.V1Beta1\312\002 Google\\Cloud\\DataCatalog\\V1beta1\352\002#Google::Cloud::DataCatalog::V1beta1",
    serialized_pb=b'\n=google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x37google/cloud/datacatalog_v1beta1/proto/timestamps.proto\x1a\x1egoogle/iam/v1/iam_policy.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xe3\x02\n\x08Taxonomy\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12Z\n\x16\x61\x63tivated_policy_types\x18\x06 \x03(\x0e\x32\x35.google.cloud.datacatalog.v1beta1.Taxonomy.PolicyTypeB\x03\xe0\x41\x01"J\n\nPolicyType\x12\x1b\n\x17POLICY_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x46INE_GRAINED_ACCESS_CONTROL\x10\x01:g\xea\x41\x64\n#datacatalog.googleapis.com/Taxonomy\x12=projects/{project}/locations/{location}/taxonomies/{taxonomy}"\x8c\x02\n\tPolicyTag\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11parent_policy_tag\x18\x04 \x01(\t\x12\x1e\n\x11\x63hild_policy_tags\x18\x05 \x03(\tB\x03\xe0\x41\x03:\x80\x01\xea\x41}\n$datacatalog.googleapis.com/PolicyTag\x12Uprojects/{project}/locations/{location}/taxonomies/{taxonomy}/policyTags/{policy_tag}"\x92\x01\n\x15\x43reateTaxonomyRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\x12#datacatalog.googleapis.com/Taxonomy\x12<\n\x08taxonomy\x18\x02 \x01(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy"R\n\x15\x44\x65leteTaxonomyRequest\x12\x39\n\x04name\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#datacatalog.googleapis.com/Taxonomy"\x86\x01\n\x15UpdateTaxonomyRequest\x12<\n\x08taxonomy\x18\x01 \x01(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"{\n\x15ListTaxonomiesRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\x12#datacatalog.googleapis.com/Taxonomy\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"q\n\x16ListTaxonomiesResponse\x12>\n\ntaxonomies\x18\x01 \x03(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"O\n\x12GetTaxonomyRequest\x12\x39\n\x04name\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#datacatalog.googleapis.com/Taxonomy"\x97\x01\n\x16\x43reatePolicyTagRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$datacatalog.googleapis.com/PolicyTag\x12?\n\npolicy_tag\x18\x02 \x01(\x0b\x32+.google.cloud.datacatalog.v1beta1.PolicyTag"T\n\x16\x44\x65letePolicyTagRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$datacatalog.googleapis.com/PolicyTag"\x8a\x01\n\x16UpdatePolicyTagRequest\x12?\n\npolicy_tag\x18\x01 \x01(\x0b\x32+.google.cloud.datacatalog.v1beta1.PolicyTag\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"|\n\x15ListPolicyTagsRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$datacatalog.googleapis.com/PolicyTag\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"s\n\x16ListPolicyTagsResponse\x12@\n\x0bpolicy_tags\x18\x01 \x03(\x0b\x32+.google.cloud.datacatalog.v1beta1.PolicyTag\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"Q\n\x13GetPolicyTagRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$datacatalog.googleapis.com/PolicyTag2\xe5\x16\n\x10PolicyTagManager\x12\xce\x01\n\x0e\x43reateTaxonomy\x12\x37.google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest\x1a*.google.cloud.datacatalog.v1beta1.Taxonomy"W\x82\xd3\xe4\x93\x02?"3/v1beta1/{parent=projects/*/locations/*}/taxonomies:\x08taxonomy\xda\x41\x0fparent,taxonomy\x12\xa5\x01\n\x0e\x44\x65leteTaxonomy\x12\x37.google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest\x1a\x16.google.protobuf.Empty"B\x82\xd3\xe4\x93\x02\x35*3/v1beta1/{name=projects/*/locations/*/taxonomies/*}\xda\x41\x04name\x12\xd0\x01\n\x0eUpdateTaxonomy\x12\x37.google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest\x1a*.google.cloud.datacatalog.v1beta1.Taxonomy"Y\x82\xd3\xe4\x93\x02H2</v1beta1/{taxonomy.name=projects/*/locations/*/taxonomies/*}:\x08taxonomy\xda\x41\x08taxonomy\x12\xc9\x01\n\x0eListTaxonomies\x12\x37.google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest\x1a\x38.google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse"D\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta1/{parent=projects/*/locations/*}/taxonomies\xda\x41\x06parent\x12\xb3\x01\n\x0bGetTaxonomy\x12\x34.google.cloud.datacatalog.v1beta1.GetTaxonomyRequest\x1a*.google.cloud.datacatalog.v1beta1.Taxonomy"B\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta1/{name=projects/*/locations/*/taxonomies/*}\xda\x41\x04name\x12\xe2\x01\n\x0f\x43reatePolicyTag\x12\x38.google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest\x1a+.google.cloud.datacatalog.v1beta1.PolicyTag"h\x82\xd3\xe4\x93\x02N"@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags:\npolicy_tag\xda\x41\x11parent,policy_tag\x12\xb4\x01\n\x0f\x44\x65letePolicyTag\x12\x38.google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest\x1a\x16.google.protobuf.Empty"O\x82\xd3\xe4\x93\x02\x42*@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\xda\x41\x04name\x12\xe6\x01\n\x0fUpdatePolicyTag\x12\x38.google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest\x1a+.google.cloud.datacatalog.v1beta1.PolicyTag"l\x82\xd3\xe4\x93\x02Y2K/v1beta1/{policy_tag.name=projects/*/locations/*/taxonomies/*/policyTags/*}:\npolicy_tag\xda\x41\npolicy_tag\x12\xd6\x01\n\x0eListPolicyTags\x12\x37.google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest\x1a\x38.google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse"Q\x82\xd3\xe4\x93\x02\x42\x12@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags\xda\x41\x06parent\x12\xc3\x01\n\x0cGetPolicyTag\x12\x35.google.cloud.datacatalog.v1beta1.GetPolicyTagRequest\x1a+.google.cloud.datacatalog.v1beta1.PolicyTag"O\x82\xd3\xe4\x93\x02\x42\x12@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\xda\x41\x04name\x12\xf4\x01\n\x0cGetIamPolicy\x12".google.iam.v1.GetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"\xa8\x01\x82\xd3\xe4\x93\x02\xa1\x01"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:getIamPolicy:\x01*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:getIamPolicy:\x01*\x12\xf4\x01\n\x0cSetIamPolicy\x12".google.iam.v1.SetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"\xa8\x01\x82\xd3\xe4\x93\x02\xa1\x01"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:setIamPolicy:\x01*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:setIamPolicy:\x01*\x12\xa0\x02\n\x12TestIamPermissions\x12(.google.iam.v1.TestIamPermissionsRequest\x1a).google.iam.v1.TestIamPermissionsResponse"\xb4\x01\x82\xd3\xe4\x93\x02\xad\x01"J/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:testIamPermissions:\x01*Z\\"W/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:testIamPermissions:\x01*\x1aN\xca\x41\x1a\x64\x61tacatalog.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xfb\x01\n$com.google.cloud.datacatalog.v1beta1B\x15PolicyTagManagerProtoP\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\xaa\x02 Google.Cloud.DataCatalog.V1Beta1\xca\x02 Google\\Cloud\\DataCatalog\\V1beta1\xea\x02#Google::Cloud::DataCatalog::V1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_iam__policy__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_TAXONOMY_POLICYTYPE = _descriptor.EnumDescriptor(
    name="PolicyType",
    full_name="google.cloud.datacatalog.v1beta1.Taxonomy.PolicyType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="POLICY_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FINE_GRAINED_ACCESS_CONTROL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=571,
    serialized_end=645,
)
_sym_db.RegisterEnumDescriptor(_TAXONOMY_POLICYTYPE)


_TAXONOMY = _descriptor.Descriptor(
    name="Taxonomy",
    full_name="google.cloud.datacatalog.v1beta1.Taxonomy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="activated_policy_types",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.activated_policy_types",
            index=3,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_TAXONOMY_POLICYTYPE],
    serialized_options=b"\352Ad\n#datacatalog.googleapis.com/Taxonomy\022=projects/{project}/locations/{location}/taxonomies/{taxonomy}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=395,
    serialized_end=750,
)


_POLICYTAG = _descriptor.Descriptor(
    name="PolicyTag",
    full_name="google.cloud.datacatalog.v1beta1.PolicyTag",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="parent_policy_tag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.parent_policy_tag",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="child_policy_tags",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.child_policy_tags",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A}\n$datacatalog.googleapis.com/PolicyTag\022Uprojects/{project}/locations/{location}/taxonomies/{taxonomy}/policyTags/{policy_tag}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=753,
    serialized_end=1021,
)


_CREATETAXONOMYREQUEST = _descriptor.Descriptor(
    name="CreateTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\022#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="taxonomy",
            full_name="google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest.taxonomy",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1024,
    serialized_end=1170,
)


_DELETETAXONOMYREQUEST = _descriptor.Descriptor(
    name="DeleteTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\n#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1172,
    serialized_end=1254,
)


_UPDATETAXONOMYREQUEST = _descriptor.Descriptor(
    name="UpdateTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomy",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest.taxonomy",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1257,
    serialized_end=1391,
)


_LISTTAXONOMIESREQUEST = _descriptor.Descriptor(
    name="ListTaxonomiesRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\022#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1393,
    serialized_end=1516,
)


_LISTTAXONOMIESRESPONSE = _descriptor.Descriptor(
    name="ListTaxonomiesResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse.taxonomies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1518,
    serialized_end=1631,
)


_GETTAXONOMYREQUEST = _descriptor.Descriptor(
    name="GetTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetTaxonomyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\n#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1633,
    serialized_end=1712,
)


_CREATEPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="CreatePolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="policy_tag",
            full_name="google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest.policy_tag",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1715,
    serialized_end=1866,
)


_DELETEPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="DeletePolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1868,
    serialized_end=1952,
)


_UPDATEPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="UpdatePolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="policy_tag",
            full_name="google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest.policy_tag",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1955,
    serialized_end=2093,
)


_LISTPOLICYTAGSREQUEST = _descriptor.Descriptor(
    name="ListPolicyTagsRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2095,
    serialized_end=2219,
)


_LISTPOLICYTAGSRESPONSE = _descriptor.Descriptor(
    name="ListPolicyTagsResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="policy_tags",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse.policy_tags",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2221,
    serialized_end=2336,
)


_GETPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="GetPolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetPolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetPolicyTagRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2338,
    serialized_end=2419,
)

_TAXONOMY.fields_by_name["activated_policy_types"].enum_type = _TAXONOMY_POLICYTYPE
_TAXONOMY_POLICYTYPE.containing_type = _TAXONOMY
_CREATETAXONOMYREQUEST.fields_by_name["taxonomy"].message_type = _TAXONOMY
_UPDATETAXONOMYREQUEST.fields_by_name["taxonomy"].message_type = _TAXONOMY
_UPDATETAXONOMYREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTAXONOMIESRESPONSE.fields_by_name["taxonomies"].message_type = _TAXONOMY
_CREATEPOLICYTAGREQUEST.fields_by_name["policy_tag"].message_type = _POLICYTAG
_UPDATEPOLICYTAGREQUEST.fields_by_name["policy_tag"].message_type = _POLICYTAG
_UPDATEPOLICYTAGREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTPOLICYTAGSRESPONSE.fields_by_name["policy_tags"].message_type = _POLICYTAG
DESCRIPTOR.message_types_by_name["Taxonomy"] = _TAXONOMY
DESCRIPTOR.message_types_by_name["PolicyTag"] = _POLICYTAG
DESCRIPTOR.message_types_by_name["CreateTaxonomyRequest"] = _CREATETAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["DeleteTaxonomyRequest"] = _DELETETAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["UpdateTaxonomyRequest"] = _UPDATETAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["ListTaxonomiesRequest"] = _LISTTAXONOMIESREQUEST
DESCRIPTOR.message_types_by_name["ListTaxonomiesResponse"] = _LISTTAXONOMIESRESPONSE
DESCRIPTOR.message_types_by_name["GetTaxonomyRequest"] = _GETTAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["CreatePolicyTagRequest"] = _CREATEPOLICYTAGREQUEST
DESCRIPTOR.message_types_by_name["DeletePolicyTagRequest"] = _DELETEPOLICYTAGREQUEST
DESCRIPTOR.message_types_by_name["UpdatePolicyTagRequest"] = _UPDATEPOLICYTAGREQUEST
DESCRIPTOR.message_types_by_name["ListPolicyTagsRequest"] = _LISTPOLICYTAGSREQUEST
DESCRIPTOR.message_types_by_name["ListPolicyTagsResponse"] = _LISTPOLICYTAGSRESPONSE
DESCRIPTOR.message_types_by_name["GetPolicyTagRequest"] = _GETPOLICYTAGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Taxonomy = _reflection.GeneratedProtocolMessageType(
    "Taxonomy",
    (_message.Message,),
    {
        "DESCRIPTOR": _TAXONOMY,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """A taxonomy is a collection of policy tags that classify
  data along a common axis. For instance a data *sensitivity* taxonomy
  could contain policy tags denoting PII such as age, zipcode, and SSN. A
  data *origin* taxonomy could contain policy tags to distinguish user
  data, employee data, partner data, public data.
  
  
  Attributes:
      name:
          Output only. Resource name of this taxonomy, whose format is: 
          “projects/{project_number}/locations/{location_id}/taxonomies/
          {id}”.
      display_name:
          Required. User defined name of this taxonomy. It must: contain
          only unicode letters, numbers, underscores, dashes and spaces;
          not start or end with spaces; and be at most 200 bytes long
          when encoded in UTF-8.
      description:
          Optional. Description of this taxonomy. It must: contain only
          unicode characters, tabs, newlines, carriage returns and page
          breaks; and be at most 2000 bytes long when encoded in UTF-8.
          If not set, defaults to an empty description.
      activated_policy_types:
          Optional. A list of policy types that are activated for this
          taxonomy. If not set, defaults to an empty list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Taxonomy)
    },
)
_sym_db.RegisterMessage(Taxonomy)

PolicyTag = _reflection.GeneratedProtocolMessageType(
    "PolicyTag",
    (_message.Message,),
    {
        "DESCRIPTOR": _POLICYTAG,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Denotes one policy tag in a taxonomy (e.g. ssn). Policy
  Tags can be defined in a hierarchy. For example, consider the following
  hierarchy: Geolocation -> (LatLong, City, ZipCode). PolicyTag
  “Geolocation” contains three child policy tags: “LatLong”, “City”, and
  “ZipCode”.
  
  
  Attributes:
      name:
          Output only. Resource name of this policy tag, whose format
          is: “projects/{project_number}/locations/{location_id}/taxonom
          ies/{taxonomy_id}/policyTags/{id}”.
      display_name:
          Required. User defined name of this policy tag. It must: be
          unique within the parent taxonomy; contain only unicode
          letters, numbers, underscores, dashes and spaces; not start or
          end with spaces; and be at most 200 bytes long when encoded in
          UTF-8.
      description:
          Description of this policy tag. It must: contain only unicode
          characters, tabs, newlines, carriage returns and page breaks;
          and be at most 2000 bytes long when encoded in UTF-8. If not
          set, defaults to an empty description. If not set, defaults to
          an empty description.
      parent_policy_tag:
          Resource name of this policy tag’s parent policy tag (e.g. for
          the “LatLong” policy tag in the example above, this field
          contains the resource name of the “Geolocation” policy tag).
          If empty, it means this policy tag is a top level policy tag
          (e.g. this field is empty for the “Geolocation” policy tag in
          the example above). If not set, defaults to an empty string.
      child_policy_tags:
          Output only. Resource names of child policy tags of this
          policy tag.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.PolicyTag)
    },
)
_sym_db.RegisterMessage(PolicyTag)

CreateTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATETAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [CreateTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.CreateTaxonomy].
  
  
  Attributes:
      parent:
          Required. Resource name of the project that the taxonomy will
          belong to.
      taxonomy:
          The taxonomy to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(CreateTaxonomyRequest)

DeleteTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [DeleteTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.DeleteTaxonomy].
  
  
  Attributes:
      name:
          Required. Resource name of the taxonomy to be deleted. All
          policy tags in this taxonomy will also be deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(DeleteTaxonomyRequest)

UpdateTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [UpdateTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdateTaxonomy].
  
  
  Attributes:
      taxonomy:
          The taxonomy to update. Only description, display_name, and
          activated policy types can be updated.
      update_mask:
          The update mask applies to the resource. For the ``FieldMask``
          definition, see https://developers.google.com/protocol-
          buffers/docs/reference/google.protobuf#fieldmask If not set,
          defaults to all of the fields that are allowed to update.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(UpdateTaxonomyRequest)

ListTaxonomiesRequest = _reflection.GeneratedProtocolMessageType(
    "ListTaxonomiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTAXONOMIESREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [ListTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListTaxonomies].
  
  
  Attributes:
      parent:
          Required. Resource name of the project to list the taxonomies
          of.
      page_size:
          The maximum number of items to return. Must be a value between
          1 and 1000. If not set, defaults to 50.
      page_token:
          The next_page_token value returned from a previous list
          request, if any. If not set, defaults to an empty string.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest)
    },
)
_sym_db.RegisterMessage(ListTaxonomiesRequest)

ListTaxonomiesResponse = _reflection.GeneratedProtocolMessageType(
    "ListTaxonomiesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTAXONOMIESRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Response message for
  [ListTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListTaxonomies].
  
  
  Attributes:
      taxonomies:
          Taxonomies that the project contains.
      next_page_token:
          Token used to retrieve the next page of results, or empty if
          there are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse)
    },
)
_sym_db.RegisterMessage(ListTaxonomiesResponse)

GetTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "GetTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETTAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [GetTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.GetTaxonomy].
  
  
  Attributes:
      name:
          Required. Resource name of the requested taxonomy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(GetTaxonomyRequest)

CreatePolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "CreatePolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [CreatePolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.CreatePolicyTag].
  
  
  Attributes:
      parent:
          Required. Resource name of the taxonomy that the policy tag
          will belong to.
      policy_tag:
          The policy tag to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest)
    },
)
_sym_db.RegisterMessage(CreatePolicyTagRequest)

DeletePolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "DeletePolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [DeletePolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.DeletePolicyTag].
  
  
  Attributes:
      name:
          Required. Resource name of the policy tag to be deleted. All
          of its descendant policy tags will also be deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest)
    },
)
_sym_db.RegisterMessage(DeletePolicyTagRequest)

UpdatePolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "UpdatePolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [UpdatePolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdatePolicyTag].
  
  
  Attributes:
      policy_tag:
          The policy tag to update. Only the description, display_name,
          and parent_policy_tag fields can be updated.
      update_mask:
          The update mask applies to the resource. Only display_name,
          description and parent_policy_tag can be updated and thus can
          be listed in the mask. If update_mask is not provided, all
          allowed fields (i.e. display_name, description and parent)
          will be updated. For more information including the
          ``FieldMask`` definition, see
          https://developers.google.com/protocol-
          buffers/docs/reference/google.protobuf#fieldmask If not set,
          defaults to all of the fields that are allowed to update.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest)
    },
)
_sym_db.RegisterMessage(UpdatePolicyTagRequest)

ListPolicyTagsRequest = _reflection.GeneratedProtocolMessageType(
    "ListPolicyTagsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTPOLICYTAGSREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [ListPolicyTags][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListPolicyTags].
  
  
  Attributes:
      parent:
          Required. Resource name of the taxonomy to list the policy
          tags of.
      page_size:
          The maximum number of items to return. Must be a value between
          1 and 1000. If not set, defaults to 50.
      page_token:
          The next_page_token value returned from a previous List
          request, if any. If not set, defaults to an empty string.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest)
    },
)
_sym_db.RegisterMessage(ListPolicyTagsRequest)

ListPolicyTagsResponse = _reflection.GeneratedProtocolMessageType(
    "ListPolicyTagsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTPOLICYTAGSRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Response message for
  [ListPolicyTags][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListPolicyTags].
  
  
  Attributes:
      policy_tags:
          The policy tags that are in the requested taxonomy.
      next_page_token:
          Token used to retrieve the next page of results, or empty if
          there are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse)
    },
)
_sym_db.RegisterMessage(ListPolicyTagsResponse)

GetPolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "GetPolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [GetPolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.GetPolicyTag].
  
  
  Attributes:
      name:
          Required. Resource name of the requested policy tag.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetPolicyTagRequest)
    },
)
_sym_db.RegisterMessage(GetPolicyTagRequest)


DESCRIPTOR._options = None
_TAXONOMY.fields_by_name["name"]._options = None
_TAXONOMY.fields_by_name["display_name"]._options = None
_TAXONOMY.fields_by_name["description"]._options = None
_TAXONOMY.fields_by_name["activated_policy_types"]._options = None
_TAXONOMY._options = None
_POLICYTAG.fields_by_name["name"]._options = None
_POLICYTAG.fields_by_name["display_name"]._options = None
_POLICYTAG.fields_by_name["child_policy_tags"]._options = None
_POLICYTAG._options = None
_CREATETAXONOMYREQUEST.fields_by_name["parent"]._options = None
_DELETETAXONOMYREQUEST.fields_by_name["name"]._options = None
_LISTTAXONOMIESREQUEST.fields_by_name["parent"]._options = None
_GETTAXONOMYREQUEST.fields_by_name["name"]._options = None
_CREATEPOLICYTAGREQUEST.fields_by_name["parent"]._options = None
_DELETEPOLICYTAGREQUEST.fields_by_name["name"]._options = None
_LISTPOLICYTAGSREQUEST.fields_by_name["parent"]._options = None
_GETPOLICYTAGREQUEST.fields_by_name["name"]._options = None

_POLICYTAGMANAGER = _descriptor.ServiceDescriptor(
    name="PolicyTagManager",
    full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\032datacatalog.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=2422,
    serialized_end=5339,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.CreateTaxonomy",
            index=0,
            containing_service=None,
            input_type=_CREATETAXONOMYREQUEST,
            output_type=_TAXONOMY,
            serialized_options=b'\202\323\344\223\002?"3/v1beta1/{parent=projects/*/locations/*}/taxonomies:\010taxonomy\332A\017parent,taxonomy',
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.DeleteTaxonomy",
            index=1,
            containing_service=None,
            input_type=_DELETETAXONOMYREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\0025*3/v1beta1/{name=projects/*/locations/*/taxonomies/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdateTaxonomy",
            index=2,
            containing_service=None,
            input_type=_UPDATETAXONOMYREQUEST,
            output_type=_TAXONOMY,
            serialized_options=b"\202\323\344\223\002H2</v1beta1/{taxonomy.name=projects/*/locations/*/taxonomies/*}:\010taxonomy\332A\010taxonomy",
        ),
        _descriptor.MethodDescriptor(
            name="ListTaxonomies",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.ListTaxonomies",
            index=3,
            containing_service=None,
            input_type=_LISTTAXONOMIESREQUEST,
            output_type=_LISTTAXONOMIESRESPONSE,
            serialized_options=b"\202\323\344\223\0025\0223/v1beta1/{parent=projects/*/locations/*}/taxonomies\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="GetTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.GetTaxonomy",
            index=4,
            containing_service=None,
            input_type=_GETTAXONOMYREQUEST,
            output_type=_TAXONOMY,
            serialized_options=b"\202\323\344\223\0025\0223/v1beta1/{name=projects/*/locations/*/taxonomies/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="CreatePolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.CreatePolicyTag",
            index=5,
            containing_service=None,
            input_type=_CREATEPOLICYTAGREQUEST,
            output_type=_POLICYTAG,
            serialized_options=b'\202\323\344\223\002N"@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags:\npolicy_tag\332A\021parent,policy_tag',
        ),
        _descriptor.MethodDescriptor(
            name="DeletePolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.DeletePolicyTag",
            index=6,
            containing_service=None,
            input_type=_DELETEPOLICYTAGREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002B*@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="UpdatePolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdatePolicyTag",
            index=7,
            containing_service=None,
            input_type=_UPDATEPOLICYTAGREQUEST,
            output_type=_POLICYTAG,
            serialized_options=b"\202\323\344\223\002Y2K/v1beta1/{policy_tag.name=projects/*/locations/*/taxonomies/*/policyTags/*}:\npolicy_tag\332A\npolicy_tag",
        ),
        _descriptor.MethodDescriptor(
            name="ListPolicyTags",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.ListPolicyTags",
            index=8,
            containing_service=None,
            input_type=_LISTPOLICYTAGSREQUEST,
            output_type=_LISTPOLICYTAGSRESPONSE,
            serialized_options=b"\202\323\344\223\002B\022@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="GetPolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.GetPolicyTag",
            index=9,
            containing_service=None,
            input_type=_GETPOLICYTAGREQUEST,
            output_type=_POLICYTAG,
            serialized_options=b"\202\323\344\223\002B\022@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="GetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.GetIamPolicy",
            index=10,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._GETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=b'\202\323\344\223\002\241\001"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:getIamPolicy:\001*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:getIamPolicy:\001*',
        ),
        _descriptor.MethodDescriptor(
            name="SetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.SetIamPolicy",
            index=11,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._SETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=b'\202\323\344\223\002\241\001"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:setIamPolicy:\001*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:setIamPolicy:\001*',
        ),
        _descriptor.MethodDescriptor(
            name="TestIamPermissions",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.TestIamPermissions",
            index=12,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSREQUEST,
            output_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSRESPONSE,
            serialized_options=b'\202\323\344\223\002\255\001"J/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:testIamPermissions:\001*Z\\"W/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:testIamPermissions:\001*',
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_POLICYTAGMANAGER)

DESCRIPTOR.services_by_name["PolicyTagManager"] = _POLICYTAGMANAGER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Accesses the google.cloud.datacatalog.v1beta1 PolicyTagManager API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.client_options
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.gapic_v1.routing_header
import google.api_core.grpc_helpers
import google.api_core.page_iterator
import google.api_core.path_template
import grpc

from google.cloud.datacatalog_v1beta1.gapic import enums
from google.cloud.datacatalog_v1beta1.gapic import policy_tag_manager_client_config
from google.cloud.datacatalog_v1beta1.gapic.transports import (
    policy_tag_manager_grpc_transport,
)
from google.cloud.datacatalog_v1beta1.proto import datacatalog_pb2
from google.cloud.datacatalog_v1beta1.proto import datacatalog_pb2_grpc
from google.cloud.datacatalog_v1beta1.proto import policytagmanager_pb2
from google.cloud.datacatalog_v1beta1.proto import policytagmanager_pb2_grpc
from google.cloud.datacatalog_v1beta1.proto import tags_pb2
from google.iam.v1 import iam_policy_pb2
from google.iam.v1 import options_pb2
from google.iam.v1 import policy_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2


_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
    "google-cloud-datacatalog"
).version


class PolicyTagManagerClient(object):
    """
    The policy tag manager API service allows clients to manage their taxonomies
    and policy tags.
    """

    SERVICE_ADDRESS = "datacatalog.googleapis.com:443"
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = "google.cloud.datacatalog.v1beta1.PolicyTagManager"

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            PolicyTagManagerClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(filename)
        kwargs["credentials"] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def location_path(cls, project, location):
        """Return a fully-qualified location string."""
        return google.api_core.path_template.expand(
            "projects/{project}/locations/{location}",
            project=project,
            location=location,
        )

    @classmethod
    def policy_tag_path(cls, project, location, taxonomy, policy_tag):
        """Return a fully-qualified policy_tag string."""
        return google.api_core.path_template.expand(
            "projects/{project}/locations/{location}/taxonomies/{taxonomy}/policyTags/{policy_tag}",
            project=project,
            location=location,
            taxonomy=taxonomy,
            policy_tag=policy_tag,
        )

    @classmethod
    def taxonomy_path(cls, project, location, taxonomy):
        """Return a fully-qualified taxonomy string."""
        return google.api_core.path_template.expand(
            "projects/{project}/locations/{location}/taxonomies/{taxonomy}",
            project=project,
            location=location,
            taxonomy=taxonomy,
        )

    def __init__(
        self,
        transport=None,
        channel=None,
        credentials=None,
        client_config=None,
        client_info=None,
        client_options=None,
    ):
        """Constructor.

        Args:
            transport (Union[~.PolicyTagManagerGrpcTransport,
                    Callable[[~.Credentials, type], ~.PolicyTagManagerGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            client_options (Union[dict, google.api_core.client_options.ClientOptions]):
                Client options used to set user options on the client. API Endpoint
                should be set through client_options.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                "The `client_config` argument is deprecated.",
                PendingDeprecationWarning,
                stacklevel=2,
            )
        else:
            client_config = policy_tag_manager_client_config.config

        if channel:
            warnings.warn(
                "The `channel` argument is deprecated; use " "`transport` instead.",
                PendingDeprecationWarning,
                stacklevel=2,
            )

        api_endpoint = self.SERVICE_ADDRESS
        if client_options:
            if type(client_options) == dict:
                client_options = google.api_core.client_options.from_dict(
                    client_options
                )
            if client_options.api_endpoint:
                api_endpoint = client_options.api_endpoint

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=policy_tag_manager_grpc_transport.PolicyTagManagerGrpcTransport,
                    address=api_endpoint,
                )
            else:
                if credentials:
                    raise ValueError(
                        "Received both a transport instance and "
                        "credentials; these are mutually exclusive."
                    )
                self.transport = transport
        else:
            self.transport = policy_tag_manager_grpc_transport.PolicyTagManagerGrpcTransport(
                address=api_endpoint, channel=channel, credentials=credentials
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION
            )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config["interfaces"][self._INTERFACE_NAME]
        )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def create_taxonomy(
        self,
        parent,
        taxonomy=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates a taxonomy in the specified project.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> parent = client.location_path('[PROJECT]', '[LOCATION]')
            >>>
            >>> response = client.create_taxonomy(parent)

        Args:
            parent (str): Required. Resource name of the project that the taxonomy will belong to.
            taxonomy (Union[dict, ~google.cloud.datacatalog_v1beta1.types.Taxonomy]): The taxonomy to be created.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.Taxonomy`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.Taxonomy` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "create_taxonomy" not in self._inner_api_calls:
            self._inner_api_calls[
                "create_taxonomy"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_taxonomy,
                default_retry=self._method_configs["CreateTaxonomy"].retry,
                default_timeout=self._method_configs["CreateTaxonomy"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.CreateTaxonomyRequest(
            parent=parent, taxonomy=taxonomy
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["create_taxonomy"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def delete_taxonomy(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes a taxonomy. This operation will also delete all
        policy tags in this taxonomy along with their associated policies.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> name = client.taxonomy_path('[PROJECT]', '[LOCATION]', '[TAXONOMY]')
            >>>
            >>> client.delete_taxonomy(name)

        Args:
            name (str): Required. Resource name of the taxonomy to be deleted. All policy tags in
                this taxonomy will also be deleted.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "delete_taxonomy" not in self._inner_api_calls:
            self._inner_api_calls[
                "delete_taxonomy"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.delete_taxonomy,
                default_retry=self._method_configs["DeleteTaxonomy"].retry,
                default_timeout=self._method_configs["DeleteTaxonomy"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.DeleteTaxonomyRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["delete_taxonomy"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def update_taxonomy(
        self,
        taxonomy=None,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Updates a taxonomy.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> response = client.update_taxonomy()

        Args:
            taxonomy (Union[dict, ~google.cloud.datacatalog_v1beta1.types.Taxonomy]): The taxonomy to update. Only description, display_name, and
                activated policy types can be updated.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.Taxonomy`
            update_mask (Union[dict, ~google.cloud.datacatalog_v1beta1.types.FieldMask]): The update mask applies to the resource. For the ``FieldMask``
                definition, see
                https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
                If not set, defaults to all of the fields that are allowed to update.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.Taxonomy` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "update_taxonomy" not in self._inner_api_calls:
            self._inner_api_calls[
                "update_taxonomy"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.update_taxonomy,
                default_retry=self._method_configs["UpdateTaxonomy"].retry,
                default_timeout=self._method_configs["UpdateTaxonomy"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.UpdateTaxonomyRequest(
            taxonomy=taxonomy, update_mask=update_mask
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("taxonomy.name", taxonomy.name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["update_taxonomy"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def list_taxonomies(
        self,
        parent,
        page_size=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists all taxonomies in a project in a particular location that the caller
        has permission to view.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> parent = client.location_path('[PROJECT]', '[LOCATION]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_taxonomies(parent):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_taxonomies(parent).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. Resource name of the project to list the taxonomies of.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.datacatalog_v1beta1.types.Taxonomy` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_taxonomies" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_taxonomies"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_taxonomies,
                default_retry=self._method_configs["ListTaxonomies"].retry,
                default_timeout=self._method_configs["ListTaxonomies"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.ListTaxonomiesRequest(
            parent=parent, page_size=page_size
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_taxonomies"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="taxonomies",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def get_taxonomy(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets a taxonomy.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> name = client.taxonomy_path('[PROJECT]', '[LOCATION]', '[TAXONOMY]')
            >>>
            >>> response = client.get_taxonomy(name)

        Args:
            name (str): Required. Resource name of the requested taxonomy.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.Taxonomy` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_taxonomy" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_taxonomy"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_taxonomy,
                default_retry=self._method_configs["GetTaxonomy"].retry,
                default_timeout=self._method_configs["GetTaxonomy"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.GetTaxonomyRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_taxonomy"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def create_policy_tag(
        self,
        parent,
        policy_tag=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates a policy tag in the specified taxonomy.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> parent = client.taxonomy_path('[PROJECT]', '[LOCATION]', '[TAXONOMY]')
            >>>
            >>> response = client.create_policy_tag(parent)

        Args:
            parent (str): Required. Resource name of the taxonomy that the policy tag will belong to.
            policy_tag (Union[dict, ~google.cloud.datacatalog_v1beta1.types.PolicyTag]): The policy tag to be created.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.PolicyTag`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.PolicyTag` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "create_policy_tag" not in self._inner_api_calls:
            self._inner_api_calls[
                "create_policy_tag"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_policy_tag,
                default_retry=self._method_configs["CreatePolicyTag"].retry,
                default_timeout=self._method_configs["CreatePolicyTag"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.CreatePolicyTagRequest(
            parent=parent, policy_tag=policy_tag
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["create_policy_tag"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def delete_policy_tag(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes a policy tag. Also deletes all of its descendant policy tags.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> name = client.policy_tag_path('[PROJECT]', '[LOCATION]', '[TAXONOMY]', '[POLICY_TAG]')
            >>>
            >>> client.delete_policy_tag(name)

        Args:
            name (str): Required. Resource name of the policy tag to be deleted. All of its descendant
                policy tags will also be deleted.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "delete_policy_tag" not in self._inner_api_calls:
            self._inner_api_calls[
                "delete_policy_tag"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.delete_policy_tag,
                default_retry=self._method_configs["DeletePolicyTag"].retry,
                default_timeout=self._method_configs["DeletePolicyTag"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.DeletePolicyTagRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["delete_policy_tag"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def update_policy_tag(
        self,
        policy_tag=None,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Updates a policy tag.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> response = client.update_policy_tag()

        Args:
            policy_tag (Union[dict, ~google.cloud.datacatalog_v1beta1.types.PolicyTag]): The policy tag to update. Only the description, display_name, and
                parent_policy_tag fields can be updated.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.PolicyTag`
            update_mask (Union[dict, ~google.cloud.datacatalog_v1beta1.types.FieldMask]): The update mask applies to the resource. Only display_name,
                description and parent_policy_tag can be updated and thus can be listed
                in the mask. If update_mask is not provided, all allowed fields (i.e.
                display_name, description and parent) will be updated. For more
                information including the ``FieldMask`` definition, see
                https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
                If not set, defaults to all of the fields that are allowed to update.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.PolicyTag` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "update_policy_tag" not in self._inner_api_calls:
            self._inner_api_calls[
                "update_policy_tag"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.update_policy_tag,
                default_retry=self._method_configs["UpdatePolicyTag"].retry,
                default_timeout=self._method_configs["UpdatePolicyTag"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.UpdatePolicyTagRequest(
            policy_tag=policy_tag, update_mask=update_mask
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("policy_tag.name", policy_tag.name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["update_policy_tag"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def list_policy_tags(
        self,
        parent,
        page_size=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists all policy tags in a taxonomy.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> parent = client.taxonomy_path('[PROJECT]', '[LOCATION]', '[TAXONOMY]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_policy_tags(parent):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_policy_tags(parent).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. Resource name of the taxonomy to list the policy tags of.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.datacatalog_v1beta1.types.PolicyTag` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_policy_tags" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_policy_tags"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_policy_tags,
                default_retry=self._method_configs["ListPolicyTags"].retry,
                default_timeout=self._method_configs["ListPolicyTags"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.ListPolicyTagsRequest(
            parent=parent, page_size=page_size
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_policy_tags"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="policy_tags",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def get_policy_tag(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets a policy tag.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> name = client.policy_tag_path('[PROJECT]', '[LOCATION]', '[TAXONOMY]', '[POLICY_TAG]')
            >>>
            >>> response = client.get_policy_tag(name)

        Args:
            name (str): Required. Resource name of the requested policy tag.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.PolicyTag` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_policy_tag" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_policy_tag"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_policy_tag,
                default_retry=self._method_configs["GetPolicyTag"].retry,
                default_timeout=self._method_configs["GetPolicyTag"].timeout,
                client_info=self._client_info,
            )

        request = policytagmanager_pb2.GetPolicyTagRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_policy_tag"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def get_iam_policy(
        self,
        resource,
        options_=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets the IAM policy for a taxonomy or a policy tag.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> # TODO: Initialize `resource`:
            >>> resource = ''
            >>>
            >>> response = client.get_iam_policy(resource)

        Args:
            resource (str): REQUIRED: The resource for which the policy is being requested.
                See the operation documentation for the appropriate value for this field.
            options_ (Union[dict, ~google.cloud.datacatalog_v1beta1.types.GetPolicyOptions]): OPTIONAL: A ``GetPolicyOptions`` object for specifying options to
                ``GetIamPolicy``. This field is only used by Cloud IAM.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.GetPolicyOptions`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.Policy` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_iam_policy" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_iam_policy"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_iam_policy,
                default_retry=self._method_configs["GetIamPolicy"].retry,
                default_timeout=self._method_configs["GetIamPolicy"].timeout,
                client_info=self._client_info,
            )

        request = iam_policy_pb2.GetIamPolicyRequest(
            resource=resource, options=options_
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("resource", resource)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_iam_policy"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def set_iam_policy(
        self,
        resource,
        policy,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Sets the IAM policy for a taxonomy or a policy tag.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> # TODO: Initialize `resource`:
            >>> resource = ''
            >>>
            >>> # TODO: Initialize `policy`:
            >>> policy = {}
            >>>
            >>> response = client.set_iam_policy(resource, policy)

        Args:
            resource (str): REQUIRED: The resource for which the policy is being specified.
                See the operation documentation for the appropriate value for this field.
            policy (Union[dict, ~google.cloud.datacatalog_v1beta1.types.Policy]): REQUIRED: The complete policy to be applied to the ``resource``. The
                size of the policy is limited to a few 10s of KB. An empty policy is a
                valid policy but certain Cloud Platform services (such as Projects)
                might reject them.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.datacatalog_v1beta1.types.Policy`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.Policy` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "set_iam_policy" not in self._inner_api_calls:
            self._inner_api_calls[
                "set_iam_policy"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.set_iam_policy,
                default_retry=self._method_configs["SetIamPolicy"].retry,
                default_timeout=self._method_configs["SetIamPolicy"].timeout,
                client_info=self._client_info,
            )

        request = iam_policy_pb2.SetIamPolicyRequest(resource=resource, policy=policy)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("resource", resource)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["set_iam_policy"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def test_iam_permissions(
        self,
        resource,
        permissions,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Returns the permissions that a caller has on the specified taxonomy or
        policy tag.

        Example:
            >>> from google.cloud import datacatalog_v1beta1
            >>>
            >>> client = datacatalog_v1beta1.PolicyTagManagerClient()
            >>>
            >>> # TODO: Initialize `resource`:
            >>> resource = ''
            >>>
            >>> # TODO: Initialize `permissions`:
            >>> permissions = []
            >>>
            >>> response = client.test_iam_permissions(resource, permissions)

        Args:
            resource (str): REQUIRED: The resource for which the policy detail is being requested.
                See the operation documentation for the appropriate value for this field.
            permissions (list[str]): The set of permissions to check for the ``resource``. Permissions
                with wildcards (such as '*' or 'storage.*') are not allowed. For more
                information see `IAM
                Overview <https://cloud.google.com/iam/docs/overview#permissions>`__.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.datacatalog_v1beta1.types.TestIamPermissionsResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "test_iam_permissions" not in self._inner_api_calls:
            self._inner_api_calls[
                "test_iam_permissions"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.test_iam_permissions,
                default_retry=self._method_configs["TestIamPermissions"].retry,
                default_timeout=self._method_configs["TestIamPermissions"].timeout,
                client_info=self._client_info,
            )

        request = iam_policy_pb2.TestIamPermissionsRequest(
            resource=resource, permissions=permissions
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("resource", resource)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["test_iam_permissions"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import google.api_core.grpc_helpers

from google.cloud.datacatalog_v1beta1.proto import datacatalog_pb2_grpc


class DataCatalogGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.datacatalog.v1beta1 DataCatalog API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self, channel=None, credentials=None, address="datacatalog.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
                options={
                    "grpc.max_send_message_length": -1,
                    "grpc.max_receive_message_length": -1,
                }.items(),
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            "data_catalog_stub": datacatalog_pb2_grpc.DataCatalogStub(channel)
        }

    @classmethod
    def create_channel(
        cls, address="datacatalog.googleapis.com:443", credentials=None, **kwargs
    ):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES, **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def search_catalog(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.search_catalog`.

        Searches Data Catalog for multiple resources like entries, tags that
        match a query.

        This is a custom method
        (https://cloud.google.com/apis/design/custom_methods) and does not
        return the complete resource, only the resource identifier and high
        level fields. Clients can subsequentally call ``Get`` methods.

        Note that Data Catalog search queries do not guarantee full recall.
        Query results that match your query may not be returned, even in
        subsequent result pages. Also note that results returned (and not
        returned) can vary across repeated search queries.

        See `Data Catalog Search
        Syntax <https://cloud.google.com/data-catalog/docs/how-to/search-reference>`__
        for more information.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].SearchCatalog

    @property
    def delete_entry_group(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.delete_entry_group`.

        Deletes an EntryGroup. Only entry groups that do not contain entries
        can be deleted. Users should enable the Data Catalog API in the project
        identified by the ``name`` parameter (see [Data Catalog Resource
        Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].DeleteEntryGroup

    @property
    def delete_entry(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.delete_entry`.

        Deletes an existing entry. Only entries created through
        ``CreateEntry`` method can be deleted. Users should enable the Data
        Catalog API in the project identified by the ``name`` parameter (see
        [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].DeleteEntry

    @property
    def get_entry(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.get_entry`.

        Gets an entry.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].GetEntry

    @property
    def lookup_entry(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.lookup_entry`.

        Get an entry by target resource name. This method allows clients to use
        the resource name from the source Google Cloud Platform service to get the
        Data Catalog Entry.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].LookupEntry

    @property
    def delete_tag_template(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.delete_tag_template`.

        Deletes a tag template and all tags using the template. Users should
        enable the Data Catalog API in the project identified by the ``name``
        parameter (see [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].DeleteTagTemplate

    @property
    def delete_tag_template_field(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.delete_tag_template_field`.

        Deletes a field in a tag template and all uses of that field. Users
        should enable the Data Catalog API in the project identified by the
        ``name`` parameter (see [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].DeleteTagTemplateField

    @property
    def delete_tag(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.delete_tag`.

        Deletes a tag.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].DeleteTag

    @property
    def get_iam_policy(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.get_iam_policy`.

        Gets the access control policy for a resource. A ``NOT_FOUND`` error
        is returned if the resource does not exist. An empty policy is returned
        if the resource exists but does not have a policy set on it.

        Supported resources are:

        -  Tag templates.
        -  Entries.
        -  Entry groups. Note, this method cannot be used to manage policies for
           BigQuery, Pub/Sub and any external Google Cloud Platform resources
           synced to Data Catalog.

        Callers must have following Google IAM permission

        -  ``datacatalog.tagTemplates.getIamPolicy`` to get policies on tag
           templates.
        -  ``datacatalog.entries.getIamPolicy`` to get policies on entries.
        -  ``datacatalog.entryGroups.getIamPolicy`` to get policies on entry
           groups.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].GetIamPolicy

    @property
    def create_entry_group(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.create_entry_group`.

        A maximum of 10,000 entry groups may be created per organization
        across all locations.

        Users should enable the Data Catalog API in the project identified by
        the ``parent`` parameter (see [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].CreateEntryGroup

    @property
    def update_entry_group(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.update_entry_group`.

        Updates an EntryGroup. The user should enable the Data Catalog API
        in the project identified by the ``entry_group.name`` parameter (see
        [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].UpdateEntryGroup

    @property
    def get_entry_group(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.get_entry_group`.

        Gets an EntryGroup.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].GetEntryGroup

    @property
    def list_entry_groups(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.list_entry_groups`.

        Lists entry groups.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].ListEntryGroups

    @property
    def create_entry(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.create_entry`.

        Creates an entry. Only entries of 'FILESET' type or user-specified
        type can be created.

        Users should enable the Data Catalog API in the project identified by
        the ``parent`` parameter (see [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        A maximum of 100,000 entries may be created per entry group.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].CreateEntry

    @property
    def update_entry(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.update_entry`.

        Updates an existing entry. Users should enable the Data Catalog API
        in the project identified by the ``entry.name`` parameter (see [Data
        Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].UpdateEntry

    @property
    def list_entries(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.list_entries`.

        Lists entries.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].ListEntries

    @property
    def create_tag_template(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.create_tag_template`.

        Creates a tag template. The user should enable the Data Catalog API
        in the project identified by the ``parent`` parameter (see `Data Catalog
        Resource
        Project <https://cloud.google.com/data-catalog/docs/concepts/resource-project>`__
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].CreateTagTemplate

    @property
    def get_tag_template(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.get_tag_template`.

        Gets a tag template.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].GetTagTemplate

    @property
    def update_tag_template(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.update_tag_template`.

        Updates a tag template. This method cannot be used to update the
        fields of a template. The tag template fields are represented as
        separate resources and should be updated using their own
        create/update/delete methods. Users should enable the Data Catalog API
        in the project identified by the ``tag_template.name`` parameter (see
        [Data Catalog Resource Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].UpdateTagTemplate

    @property
    def create_tag_template_field(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.create_tag_template_field`.

        Creates a field in a tag template. The user should enable the Data
        Catalog API in the project identified by the ``parent`` parameter (see
        `Data Catalog Resource
        Project <https://cloud.google.com/data-catalog/docs/concepts/resource-project>`__
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].CreateTagTemplateField

    @property
    def update_tag_template_field(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.update_tag_template_field`.

        Updates a field in a tag template. This method cannot be used to
        update the field type. Users should enable the Data Catalog API in the
        project identified by the ``name`` parameter (see [Data Catalog Resource
        Project]
        (https://cloud.google.com/data-catalog/docs/concepts/resource-project)
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].UpdateTagTemplateField

    @property
    def rename_tag_template_field(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.rename_tag_template_field`.

        Renames a field in a tag template. The user should enable the Data
        Catalog API in the project identified by the ``name`` parameter (see
        `Data Catalog Resource
        Project <https://cloud.google.com/data-catalog/docs/concepts/resource-project>`__
        for more information).

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].RenameTagTemplateField

    @property
    def create_tag(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.create_tag`.

        Creates a tag on an ``Entry``. Note: The project identified by the
        ``parent`` parameter for the
        `tag <https://cloud.google.com/data-catalog/docs/reference/rest/v1beta1/projects.locations.entryGroups.entries.tags/create#path-parameters>`__
        and the `tag
        template <https://cloud.google.com/data-catalog/docs/reference/rest/v1beta1/projects.locations.tagTemplates/create#path-parameters>`__
        used to create the tag must be from the same organization.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].CreateTag

    @property
    def update_tag(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.update_tag`.

        Updates an existing tag.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].UpdateTag

    @property
    def list_tags(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.list_tags`.

        Lists the tags on an ``Entry``.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].ListTags

    @property
    def set_iam_policy(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.set_iam_policy`.

        Sets the access control policy for a resource. Replaces any existing
        policy. Supported resources are:

        -  Tag templates.
        -  Entries.
        -  Entry groups. Note, this method cannot be used to manage policies for
           BigQuery, Pub/Sub and any external Google Cloud Platform resources
           synced to Data Catalog.

        Callers must have following Google IAM permission

        -  ``datacatalog.tagTemplates.setIamPolicy`` to set policies on tag
           templates.
        -  ``datacatalog.entries.setIamPolicy`` to set policies on entries.
        -  ``datacatalog.entryGroups.setIamPolicy`` to set policies on entry
           groups.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].SetIamPolicy

    @property
    def test_iam_permissions(self):
        """Return the gRPC stub for :meth:`DataCatalogClient.test_iam_permissions`.

        Returns the caller's permissions on a resource. If the resource does
        not exist, an empty set of permissions is returned (We don't return a
        ``NOT_FOUND`` error).

        Supported resources are:

        -  Tag templates.
        -  Entries.
        -  Entry groups. Note, this method cannot be used to manage policies for
           BigQuery, Pub/Sub and any external Google Cloud Platform resources
           synced to Data Catalog.

        A caller is not required to have Google IAM permission to make this
        request.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["data_catalog_stub"].TestIamPermissions
